function [L,U] = lu_jki(A)
%
% LU factorization (without pivoting), jki version, didactic purpose
% column-contiguos data structure (Fortran, Matlab, Octave)
%
% A = L*U

% no extra storage needed
n = length (A);
for j = 1:n
  for k = 1:j - 1
    for i = k + 1:n
      A(i, j) = A(i, j) - A(i, k) * A(k, j); % j-th column is changed
    end
  end
  for i = j + 1:n
    A(i, j) = A(i, j) / A(j, j); % j-th column is changed 
                                 % (assuming A(j, j) ~= 0
  end
end
% the matrix A now contains exactly U in the triu part and L (except the
% ones on the diagonal) on the tril part
U = triu (A);
L = A - U + eye (size (A));
%!test
%! A = rand (5);
%! [L, U] = lu_jki (A);
%! assert (A, L * U, 1e-14)